; code to flash LED on GP2 (pin 5) alternate with GP1 (pin 6)

	list      p=12f629            		; list directive to define processor
	#include <p12f629.inc>        		; processor specific variable definitions

	errorlevel  -302              		; suppress message 302 from list file

	__CONFIG   _CP_OFF & _CPD_OFF & _BODEN_OFF & _MCLRE_OFF & _WDT_OFF & _PWRTE_ON & _INTRC_OSC_NOCLKOUT  

; '__CONFIG' directive is used to embed configuration word within .asm file.
; The lables following the directive are located in the respective .inc file.
; See data sheet for additional information on configuration word settings.

;***** VARIABLE DEFINITIONS

lp3			EQU		0x20
lp2			EQU		0x21
lp1			EQU		0x22
led			EQU		0x30
button		EQU		0x31


;***** CONSTANTS

SLP3		EQU		49					; get ~0.5s interval
SLP2		EQU		39					;	256 * 131 * 15
SLP1		EQU		0xFF				;


;***** MACROS

bank0:  MACRO 
        bcf STATUS, RP0 
        ENDM 

bank1:  MACRO 
        bsf STATUS, RP0 
        ENDM 


;***** PROGRAM CODE

            ORG     0x000					; processor reset vector

            goto    Main					; go to beginning of program


            ORG     0x004					; interrupt vector location

            retfie                                    ; return from interrupt

Main

            bank1
		
; use internal pull-ups, except GP2 and GP1

            movlw	b'110001'
            movwf	WPU						; set internal pull flags
            bcf		OPTION_REG, NOT_GPPU	      ; enable internal pullups global

; set TRISIO, all input except GP2 and GP1
		
            movlw	b'111001'
            movwf	TRISIO

            bank0

            movlw   b'100'                ; initial port values       
            movwf   led
            movwf   GPIO

; main loop

Loop:       movlw   SLP1 
            movwf   lp1 

Loop1:      movlw   SLP2 
            movwf   lp2 

Loop2:      movlw   SLP3 
            movwf   lp3 

Loop3:      decfsz  lp3 
            goto    Loop3 
            decfsz  lp2 
            goto    Loop2 

            btfsc   GPIO, GP3             ; button pressed and pin goes low
            goto    Btn2

            btfss   button, 0             ; button already pressed?
            goto    Btn1                  ; - no

            btfsc   button, 1             ; button press already processed?
            goto    Btn3                  ; - yes

            movlw   b'110'                ; switch
            xorwf   led, F                ;
            movf    led, W
            movwf   GPIO
            bsf     button, 1             ; mark as button has been processed

            goto    Loop
 
Btn1:       bsf     button, 0
            goto    Btn3

Btn2:       bcf     button, 0             ; clear the button pressed flags
            bcf     button, 1             ;

Btn3:       decfsz  lp1 
            goto    Loop1

            movf    led, W                ; flash
            xorwf   GPIO, F               ;
		
            goto    Loop 

            END                  	     	; directive 'end of program'

